#!/bin/bash

# chkconfig: - 62 38
# description: Server Startup Script.
#
# Updated 2009-08-03 to accomodate upgrades
### 
###
# Configure JAVA_HOME here or in your environment
# JAVA_HOME="/usr/java/latest"

trap "" SIGHUP

BASEDIR=`dirname ${0}`
BASENAME=`basename ${0} .sh`
OKSTATUSINDICATOR="OK"

. ${BASEDIR}/config-vars.sh

PATH=$PATH:/sbin

ARG2=${2}

function performUpgrade {
	echo "--PERFORMING UPGRADE--"
	if [ -e  update/server/install.sh ]; then
		cd update/server
		/bin/sh ./install.sh
		exit 128
	fi
}

function stop {

        echo -n "Stopping ${BASENAME} "
        cd ${BASEDIR}
        kill -9 `cat ${BASENAME}.pid`
        rm ${BASENAME}.pid
        echo ${OKSTATUSINDICATOR}

}

function start {

 	if [ x${JAVA_HOME} = "x" ]; then
		echo "JAVA_HOME does not appear to be in your environment."
		echo "You must define the JAVA_HOME environment variable"
		echo "in the ${BASEDIR}/config-vars.sh shell script"
		exit 1
	else
		if [ ! -e ${JAVA_HOME}/bin/java ]; then
			echo "JAVA_HOME is defined, but the 'java' executable"
			echo "cannot be found in:  "
			echo ""
			echo "${JAVA_HOME}/bin"
			echo ""
			echo "This is a fatal error."
			echo "Verify your JAVA_HOME environment variable is set"
			echo "in ${BASEDIR}/config-vars.sh"
			exit 1

		fi
 	fi

	echo -n "Starting ${BASENAME}.. "

	cd ${BASEDIR}

	if [ -e ${BASENAME}.pid ]; then
		echo "${BASENAME} appears to be running as Process ID `cat ${BASENAME}.pid`"
		echo "Checking to see if server appears up.."
		ps -auxww | grep "${BASENAME}" | grep "`cat ${BASENAME}.pid`" |  grep -v "grep"
		if [ $? ]; then
			echo "Server appears to be down, removing PID file and continuing start process"
			rm ${BASENAME}.pid
		else
			echo "Server already running as PID `cat ${BASENAME}.pid`, exiting."
			exit 0;
		fi
	fi 

	${JAVA_HOME}/bin/java -Djava.library.path=lib -jar ${BASENAME}.jar ${BASEDIR} &
	LAUNCHPID=$!
	echo "PID is ${LAUNCHPID}"
	echo ${LAUNCHPID} > ${BASENAME}.pid
	
	wait ${LAUNCHPID}
	
	if [ $? -eq 128 ]; then
		echo "Upgrade In Progress: ${EXITVAL}"
		rm ${BASENAME}.pid
		performUpgrade
	elif [ $? -ne 0 ]; then
		echo "Abnormal Termination: ${EXITVAL}"
		echo "${BASENAME} launch failed.  Removing Lockfile."
		rm ${BASENAME}.pid
		exit 1
	else
		echo "${BASENAME} Exiting Normally.."
	fi

}

case "$1" in
	"start")
		start
	;;
	"stop")
		stop
	;;
	"restart")
		stop
		start
	;;
	*)
		echo "Usage: ${0} {start|stop|restart}"
	;;
esac

